# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ibc.core.channel.v1 import tx_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the ibc/channel Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ChannelOpenInit = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenInit',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.FromString,
                )
        self.ChannelOpenTry = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenTry',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.FromString,
                )
        self.ChannelOpenAck = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenAck',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.FromString,
                )
        self.ChannelOpenConfirm = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelOpenConfirm',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.FromString,
                )
        self.ChannelCloseInit = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelCloseInit',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.FromString,
                )
        self.ChannelCloseConfirm = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/ChannelCloseConfirm',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.FromString,
                )
        self.RecvPacket = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/RecvPacket',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.FromString,
                )
        self.Timeout = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/Timeout',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.FromString,
                )
        self.TimeoutOnClose = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/TimeoutOnClose',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.FromString,
                )
        self.Acknowledgement = channel.unary_unary(
                '/ibc.core.channel.v1.Msg/Acknowledgement',
                request_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.SerializeToString,
                response_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the ibc/channel Msg service.
    """

    def ChannelOpenInit(self, request, context):
        """ChannelOpenInit defines a rpc handler method for MsgChannelOpenInit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenTry(self, request, context):
        """ChannelOpenTry defines a rpc handler method for MsgChannelOpenTry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenAck(self, request, context):
        """ChannelOpenAck defines a rpc handler method for MsgChannelOpenAck.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelOpenConfirm(self, request, context):
        """ChannelOpenConfirm defines a rpc handler method for MsgChannelOpenConfirm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelCloseInit(self, request, context):
        """ChannelCloseInit defines a rpc handler method for MsgChannelCloseInit.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChannelCloseConfirm(self, request, context):
        """ChannelCloseConfirm defines a rpc handler method for
        MsgChannelCloseConfirm.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RecvPacket(self, request, context):
        """RecvPacket defines a rpc handler method for MsgRecvPacket.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Timeout(self, request, context):
        """Timeout defines a rpc handler method for MsgTimeout.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TimeoutOnClose(self, request, context):
        """TimeoutOnClose defines a rpc handler method for MsgTimeoutOnClose.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Acknowledgement(self, request, context):
        """Acknowledgement defines a rpc handler method for MsgAcknowledgement.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ChannelOpenInit': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenInit,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.SerializeToString,
            ),
            'ChannelOpenTry': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenTry,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.SerializeToString,
            ),
            'ChannelOpenAck': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenAck,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.SerializeToString,
            ),
            'ChannelOpenConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelOpenConfirm,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.SerializeToString,
            ),
            'ChannelCloseInit': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelCloseInit,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.SerializeToString,
            ),
            'ChannelCloseConfirm': grpc.unary_unary_rpc_method_handler(
                    servicer.ChannelCloseConfirm,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.SerializeToString,
            ),
            'RecvPacket': grpc.unary_unary_rpc_method_handler(
                    servicer.RecvPacket,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.SerializeToString,
            ),
            'Timeout': grpc.unary_unary_rpc_method_handler(
                    servicer.Timeout,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.SerializeToString,
            ),
            'TimeoutOnClose': grpc.unary_unary_rpc_method_handler(
                    servicer.TimeoutOnClose,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.SerializeToString,
            ),
            'Acknowledgement': grpc.unary_unary_rpc_method_handler(
                    servicer.Acknowledgement,
                    request_deserializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.FromString,
                    response_serializer=ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ibc.core.channel.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the ibc/channel Msg service.
    """

    @staticmethod
    def ChannelOpenInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelOpenInit',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInit.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenInitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelOpenTry(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelOpenTry',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTry.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenTryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelOpenAck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelOpenAck',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAck.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenAckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelOpenConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelOpenConfirm',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirm.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelOpenConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelCloseInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelCloseInit',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInit.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseInitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChannelCloseConfirm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/ChannelCloseConfirm',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirm.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgChannelCloseConfirmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RecvPacket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/RecvPacket',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacket.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgRecvPacketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Timeout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/Timeout',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeout.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TimeoutOnClose(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/TimeoutOnClose',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnClose.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgTimeoutOnCloseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Acknowledgement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ibc.core.channel.v1.Msg/Acknowledgement',
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgement.SerializeToString,
            ibc_dot_core_dot_channel_dot_v1_dot_tx__pb2.MsgAcknowledgementResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmwasm.wasm.v1 import types_pb2 as cosmwasm_dot_wasm_dot_v1_dot_types__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmwasm/wasm/v1/query.proto',
  package='cosmwasm.wasm.v1',
  syntax='proto3',
  serialized_options=b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000\250\342\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1c\x63osmwasm/wasm/v1/query.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\x1a\x1c\x63osmwasm/wasm/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"+\n\x18QueryContractInfoRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"w\n\x19QueryContractInfoResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x43\n\rcontract_info\x18\x02 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.ContractInfoB\x0c\xd0\xde\x1f\x01\xc8\xde\x1f\x00\xea\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"j\n\x1bQueryContractHistoryRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x9e\x01\n\x1cQueryContractHistoryResponse\x12\x41\n\x07\x65ntries\x18\x01 \x03(\x0b\x32*.cosmwasm.wasm.v1.ContractCodeHistoryEntryB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"j\n\x1bQueryContractsByCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"n\n\x1cQueryContractsByCodeResponse\x12\x11\n\tcontracts\x18\x01 \x03(\t\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"k\n\x1cQueryAllContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8b\x01\n\x1dQueryAllContractStateResponse\x12-\n\x06models\x18\x01 \x03(\x0b\x32\x17.cosmwasm.wasm.v1.ModelB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"C\n\x1cQueryRawContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x12\n\nquery_data\x18\x02 \x01(\x0c\"-\n\x1dQueryRawContractStateResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"]\n\x1eQuerySmartContractStateRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12*\n\nquery_data\x18\x02 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"G\n\x1fQuerySmartContractStateResponse\x12$\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x16\xfa\xde\x1f\x12RawContractMessage\"#\n\x10QueryCodeRequest\x12\x0f\n\x07\x63ode_id\x18\x01 \x01(\x04\"\xeb\x01\n\x10\x43odeInfoResponse\x12!\n\x07\x63ode_id\x18\x01 \x01(\x04\x42\x10\xe2\xde\x1f\x06\x43odeID\xea\xde\x1f\x02id\x12\x0f\n\x07\x63reator\x18\x02 \x01(\t\x12K\n\tdata_hash\x18\x03 \x01(\x0c\x42\x38\xfa\xde\x1f\x34github.com/tendermint/tendermint/libs/bytes.HexBytes\x12\x44\n\x16instantiate_permission\x18\x06 \x01(\x0b\x32\x1e.cosmwasm.wasm.v1.AccessConfigB\x04\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"r\n\x11QueryCodeResponse\x12?\n\tcode_info\x18\x01 \x01(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x08\xd0\xde\x1f\x01\xea\xde\x1f\x00\x12\x16\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x08\xea\xde\x1f\x04\x64\x61ta:\x04\xe8\xa0\x1f\x01\"O\n\x11QueryCodesRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x8f\x01\n\x12QueryCodesResponse\x12<\n\ncode_infos\x18\x01 \x03(\x0b\x32\".cosmwasm.wasm.v1.CodeInfoResponseB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"U\n\x17QueryPinnedCodesRequest\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"z\n\x18QueryPinnedCodesResponse\x12!\n\x08\x63ode_ids\x18\x01 \x03(\x04\x42\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x43odeIDs\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x89\x0b\n\x05Query\x12\x95\x01\n\x0c\x43ontractInfo\x12*.cosmwasm.wasm.v1.QueryContractInfoRequest\x1a+.cosmwasm.wasm.v1.QueryContractInfoResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmwasm/wasm/v1/contract/{address}\x12\xa6\x01\n\x0f\x43ontractHistory\x12-.cosmwasm.wasm.v1.QueryContractHistoryRequest\x1a..cosmwasm.wasm.v1.QueryContractHistoryResponse\"4\x82\xd3\xe4\x93\x02.\x12,/cosmwasm/wasm/v1/contract/{address}/history\x12\xa4\x01\n\x0f\x43ontractsByCode\x12-.cosmwasm.wasm.v1.QueryContractsByCodeRequest\x1a..cosmwasm.wasm.v1.QueryContractsByCodeResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/code/{code_id}/contracts\x12\xa7\x01\n\x10\x41llContractState\x12..cosmwasm.wasm.v1.QueryAllContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryAllContractStateResponse\"2\x82\xd3\xe4\x93\x02,\x12*/cosmwasm/wasm/v1/contract/{address}/state\x12\xb2\x01\n\x10RawContractState\x12..cosmwasm.wasm.v1.QueryRawContractStateRequest\x1a/.cosmwasm.wasm.v1.QueryRawContractStateResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}\x12\xba\x01\n\x12SmartContractState\x12\x30.cosmwasm.wasm.v1.QuerySmartContractStateRequest\x1a\x31.cosmwasm.wasm.v1.QuerySmartContractStateResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}\x12y\n\x04\x43ode\x12\".cosmwasm.wasm.v1.QueryCodeRequest\x1a#.cosmwasm.wasm.v1.QueryCodeResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /cosmwasm/wasm/v1/code/{code_id}\x12r\n\x05\x43odes\x12#.cosmwasm.wasm.v1.QueryCodesRequest\x1a$.cosmwasm.wasm.v1.QueryCodesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/cosmwasm/wasm/v1/code\x12\x8c\x01\n\x0bPinnedCodes\x12).cosmwasm.wasm.v1.QueryPinnedCodesRequest\x1a*.cosmwasm.wasm.v1.QueryPinnedCodesResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cosmwasm/wasm/v1/codes/pinnedB0Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\xa8\xe2\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmwasm_dot_wasm_dot_v1_dot_types__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2.DESCRIPTOR,])




_QUERYCONTRACTINFOREQUEST = _descriptor.Descriptor(
  name='QueryContractInfoRequest',
  full_name='cosmwasm.wasm.v1.QueryContractInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractInfoRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=219,
)


_QUERYCONTRACTINFORESPONSE = _descriptor.Descriptor(
  name='QueryContractInfoResponse',
  full_name='cosmwasm.wasm.v1.QueryContractInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractInfoResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_info', full_name='cosmwasm.wasm.v1.QueryContractInfoResponse.contract_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\310\336\037\000\352\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=340,
)


_QUERYCONTRACTHISTORYREQUEST = _descriptor.Descriptor(
  name='QueryContractHistoryRequest',
  full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractHistoryRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=342,
  serialized_end=448,
)


_QUERYCONTRACTHISTORYRESPONSE = _descriptor.Descriptor(
  name='QueryContractHistoryResponse',
  full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractHistoryResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=609,
)


_QUERYCONTRACTSBYCODEREQUEST = _descriptor.Descriptor(
  name='QueryContractsByCodeRequest',
  full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractsByCodeRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=717,
)


_QUERYCONTRACTSBYCODERESPONSE = _descriptor.Descriptor(
  name='QueryContractsByCodeResponse',
  full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contracts', full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse.contracts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryContractsByCodeResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=719,
  serialized_end=829,
)


_QUERYALLCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QueryAllContractStateRequest',
  full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryAllContractStateRequest.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=938,
)


_QUERYALLCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QueryAllContractStateResponse',
  full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='models', full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse.models', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryAllContractStateResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=941,
  serialized_end=1080,
)


_QUERYRAWCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QueryRawContractStateRequest',
  full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_data', full_name='cosmwasm.wasm.v1.QueryRawContractStateRequest.query_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1082,
  serialized_end=1149,
)


_QUERYRAWCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QueryRawContractStateResponse',
  full_name='cosmwasm.wasm.v1.QueryRawContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QueryRawContractStateResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1196,
)


_QUERYSMARTCONTRACTSTATEREQUEST = _descriptor.Descriptor(
  name='QuerySmartContractStateRequest',
  full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_data', full_name='cosmwasm.wasm.v1.QuerySmartContractStateRequest.query_data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\037\022RawContractMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1291,
)


_QUERYSMARTCONTRACTSTATERESPONSE = _descriptor.Descriptor(
  name='QuerySmartContractStateResponse',
  full_name='cosmwasm.wasm.v1.QuerySmartContractStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QuerySmartContractStateResponse.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\037\022RawContractMessage', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1364,
)


_QUERYCODEREQUEST = _descriptor.Descriptor(
  name='QueryCodeRequest',
  full_name='cosmwasm.wasm.v1.QueryCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.QueryCodeRequest.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1401,
)


_CODEINFORESPONSE = _descriptor.Descriptor(
  name='CodeInfoResponse',
  full_name='cosmwasm.wasm.v1.CodeInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_id', full_name='cosmwasm.wasm.v1.CodeInfoResponse.code_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\006CodeID\352\336\037\002id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator', full_name='cosmwasm.wasm.v1.CodeInfoResponse.creator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_hash', full_name='cosmwasm.wasm.v1.CodeInfoResponse.data_hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\336\0374github.com/tendermint/tendermint/libs/bytes.HexBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instantiate_permission', full_name='cosmwasm.wasm.v1.CodeInfoResponse.instantiate_permission', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1404,
  serialized_end=1639,
)


_QUERYCODERESPONSE = _descriptor.Descriptor(
  name='QueryCodeResponse',
  full_name='cosmwasm.wasm.v1.QueryCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_info', full_name='cosmwasm.wasm.v1.QueryCodeResponse.code_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\352\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.QueryCodeResponse.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\004data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1641,
  serialized_end=1755,
)


_QUERYCODESREQUEST = _descriptor.Descriptor(
  name='QueryCodesRequest',
  full_name='cosmwasm.wasm.v1.QueryCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryCodesRequest.pagination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1836,
)


_QUERYCODESRESPONSE = _descriptor.Descriptor(
  name='QueryCodesResponse',
  full_name='cosmwasm.wasm.v1.QueryCodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_infos', full_name='cosmwasm.wasm.v1.QueryCodesResponse.code_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryCodesResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1839,
  serialized_end=1982,
)


_QUERYPINNEDCODESREQUEST = _descriptor.Descriptor(
  name='QueryPinnedCodesRequest',
  full_name='cosmwasm.wasm.v1.QueryPinnedCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryPinnedCodesRequest.pagination', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1984,
  serialized_end=2069,
)


_QUERYPINNEDCODESRESPONSE = _descriptor.Descriptor(
  name='QueryPinnedCodesResponse',
  full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code_ids', full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse.code_ids', index=0,
      number=1, type=4, cpp_type=4, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\342\336\037\007CodeIDs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pagination', full_name='cosmwasm.wasm.v1.QueryPinnedCodesResponse.pagination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2193,
)

_QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._CONTRACTINFO
_QUERYCONTRACTHISTORYREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._CONTRACTCODEHISTORYENTRY
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYCONTRACTSBYCODEREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCONTRACTSBYCODERESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYALLCONTRACTSTATEREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._MODEL
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_CODEINFORESPONSE.fields_by_name['instantiate_permission'].message_type = cosmwasm_dot_wasm_dot_v1_dot_types__pb2._ACCESSCONFIG
_QUERYCODERESPONSE.fields_by_name['code_info'].message_type = _CODEINFORESPONSE
_QUERYCODESREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYCODESRESPONSE.fields_by_name['code_infos'].message_type = _CODEINFORESPONSE
_QUERYCODESRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
_QUERYPINNEDCODESREQUEST.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGEREQUEST
_QUERYPINNEDCODESRESPONSE.fields_by_name['pagination'].message_type = cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2._PAGERESPONSE
DESCRIPTOR.message_types_by_name['QueryContractInfoRequest'] = _QUERYCONTRACTINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryContractInfoResponse'] = _QUERYCONTRACTINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryContractHistoryRequest'] = _QUERYCONTRACTHISTORYREQUEST
DESCRIPTOR.message_types_by_name['QueryContractHistoryResponse'] = _QUERYCONTRACTHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['QueryContractsByCodeRequest'] = _QUERYCONTRACTSBYCODEREQUEST
DESCRIPTOR.message_types_by_name['QueryContractsByCodeResponse'] = _QUERYCONTRACTSBYCODERESPONSE
DESCRIPTOR.message_types_by_name['QueryAllContractStateRequest'] = _QUERYALLCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryAllContractStateResponse'] = _QUERYALLCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryRawContractStateRequest'] = _QUERYRAWCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryRawContractStateResponse'] = _QUERYRAWCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QuerySmartContractStateRequest'] = _QUERYSMARTCONTRACTSTATEREQUEST
DESCRIPTOR.message_types_by_name['QuerySmartContractStateResponse'] = _QUERYSMARTCONTRACTSTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryCodeRequest'] = _QUERYCODEREQUEST
DESCRIPTOR.message_types_by_name['CodeInfoResponse'] = _CODEINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryCodeResponse'] = _QUERYCODERESPONSE
DESCRIPTOR.message_types_by_name['QueryCodesRequest'] = _QUERYCODESREQUEST
DESCRIPTOR.message_types_by_name['QueryCodesResponse'] = _QUERYCODESRESPONSE
DESCRIPTOR.message_types_by_name['QueryPinnedCodesRequest'] = _QUERYPINNEDCODESREQUEST
DESCRIPTOR.message_types_by_name['QueryPinnedCodesResponse'] = _QUERYPINNEDCODESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryContractInfoRequest = _reflection.GeneratedProtocolMessageType('QueryContractInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTINFOREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractInfoRequest)
  })
_sym_db.RegisterMessage(QueryContractInfoRequest)

QueryContractInfoResponse = _reflection.GeneratedProtocolMessageType('QueryContractInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTINFORESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractInfoResponse)
  })
_sym_db.RegisterMessage(QueryContractInfoResponse)

QueryContractHistoryRequest = _reflection.GeneratedProtocolMessageType('QueryContractHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTHISTORYREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractHistoryRequest)
  })
_sym_db.RegisterMessage(QueryContractHistoryRequest)

QueryContractHistoryResponse = _reflection.GeneratedProtocolMessageType('QueryContractHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTHISTORYRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractHistoryResponse)
  })
_sym_db.RegisterMessage(QueryContractHistoryResponse)

QueryContractsByCodeRequest = _reflection.GeneratedProtocolMessageType('QueryContractsByCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTSBYCODEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractsByCodeRequest)
  })
_sym_db.RegisterMessage(QueryContractsByCodeRequest)

QueryContractsByCodeResponse = _reflection.GeneratedProtocolMessageType('QueryContractsByCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTRACTSBYCODERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryContractsByCodeResponse)
  })
_sym_db.RegisterMessage(QueryContractsByCodeResponse)

QueryAllContractStateRequest = _reflection.GeneratedProtocolMessageType('QueryAllContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryAllContractStateRequest)
  })
_sym_db.RegisterMessage(QueryAllContractStateRequest)

QueryAllContractStateResponse = _reflection.GeneratedProtocolMessageType('QueryAllContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYALLCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryAllContractStateResponse)
  })
_sym_db.RegisterMessage(QueryAllContractStateResponse)

QueryRawContractStateRequest = _reflection.GeneratedProtocolMessageType('QueryRawContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryRawContractStateRequest)
  })
_sym_db.RegisterMessage(QueryRawContractStateRequest)

QueryRawContractStateResponse = _reflection.GeneratedProtocolMessageType('QueryRawContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRAWCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryRawContractStateResponse)
  })
_sym_db.RegisterMessage(QueryRawContractStateResponse)

QuerySmartContractStateRequest = _reflection.GeneratedProtocolMessageType('QuerySmartContractStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSMARTCONTRACTSTATEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QuerySmartContractStateRequest)
  })
_sym_db.RegisterMessage(QuerySmartContractStateRequest)

QuerySmartContractStateResponse = _reflection.GeneratedProtocolMessageType('QuerySmartContractStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSMARTCONTRACTSTATERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QuerySmartContractStateResponse)
  })
_sym_db.RegisterMessage(QuerySmartContractStateResponse)

QueryCodeRequest = _reflection.GeneratedProtocolMessageType('QueryCodeRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODEREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodeRequest)
  })
_sym_db.RegisterMessage(QueryCodeRequest)

CodeInfoResponse = _reflection.GeneratedProtocolMessageType('CodeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CODEINFORESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.CodeInfoResponse)
  })
_sym_db.RegisterMessage(CodeInfoResponse)

QueryCodeResponse = _reflection.GeneratedProtocolMessageType('QueryCodeResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODERESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodeResponse)
  })
_sym_db.RegisterMessage(QueryCodeResponse)

QueryCodesRequest = _reflection.GeneratedProtocolMessageType('QueryCodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODESREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodesRequest)
  })
_sym_db.RegisterMessage(QueryCodesRequest)

QueryCodesResponse = _reflection.GeneratedProtocolMessageType('QueryCodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCODESRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryCodesResponse)
  })
_sym_db.RegisterMessage(QueryCodesResponse)

QueryPinnedCodesRequest = _reflection.GeneratedProtocolMessageType('QueryPinnedCodesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPINNEDCODESREQUEST,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryPinnedCodesRequest)
  })
_sym_db.RegisterMessage(QueryPinnedCodesRequest)

QueryPinnedCodesResponse = _reflection.GeneratedProtocolMessageType('QueryPinnedCodesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPINNEDCODESRESPONSE,
  '__module__' : 'cosmwasm.wasm.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.QueryPinnedCodesResponse)
  })
_sym_db.RegisterMessage(QueryPinnedCodesResponse)


DESCRIPTOR._options = None
_QUERYCONTRACTINFORESPONSE.fields_by_name['contract_info']._options = None
_QUERYCONTRACTINFORESPONSE._options = None
_QUERYCONTRACTHISTORYRESPONSE.fields_by_name['entries']._options = None
_QUERYALLCONTRACTSTATERESPONSE.fields_by_name['models']._options = None
_QUERYSMARTCONTRACTSTATEREQUEST.fields_by_name['query_data']._options = None
_QUERYSMARTCONTRACTSTATERESPONSE.fields_by_name['data']._options = None
_CODEINFORESPONSE.fields_by_name['code_id']._options = None
_CODEINFORESPONSE.fields_by_name['data_hash']._options = None
_CODEINFORESPONSE.fields_by_name['instantiate_permission']._options = None
_CODEINFORESPONSE._options = None
_QUERYCODERESPONSE.fields_by_name['code_info']._options = None
_QUERYCODERESPONSE.fields_by_name['data']._options = None
_QUERYCODERESPONSE._options = None
_QUERYCODESRESPONSE.fields_by_name['code_infos']._options = None
_QUERYPINNEDCODESRESPONSE.fields_by_name['code_ids']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='cosmwasm.wasm.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2196,
  serialized_end=3613,
  methods=[
  _descriptor.MethodDescriptor(
    name='ContractInfo',
    full_name='cosmwasm.wasm.v1.Query.ContractInfo',
    index=0,
    containing_service=None,
    input_type=_QUERYCONTRACTINFOREQUEST,
    output_type=_QUERYCONTRACTINFORESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/cosmwasm/wasm/v1/contract/{address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ContractHistory',
    full_name='cosmwasm.wasm.v1.Query.ContractHistory',
    index=1,
    containing_service=None,
    input_type=_QUERYCONTRACTHISTORYREQUEST,
    output_type=_QUERYCONTRACTHISTORYRESPONSE,
    serialized_options=b'\202\323\344\223\002.\022,/cosmwasm/wasm/v1/contract/{address}/history',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ContractsByCode',
    full_name='cosmwasm.wasm.v1.Query.ContractsByCode',
    index=2,
    containing_service=None,
    input_type=_QUERYCONTRACTSBYCODEREQUEST,
    output_type=_QUERYCONTRACTSBYCODERESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/code/{code_id}/contracts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AllContractState',
    full_name='cosmwasm.wasm.v1.Query.AllContractState',
    index=3,
    containing_service=None,
    input_type=_QUERYALLCONTRACTSTATEREQUEST,
    output_type=_QUERYALLCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/cosmwasm/wasm/v1/contract/{address}/state',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RawContractState',
    full_name='cosmwasm.wasm.v1.Query.RawContractState',
    index=4,
    containing_service=None,
    input_type=_QUERYRAWCONTRACTSTATEREQUEST,
    output_type=_QUERYRAWCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/cosmwasm/wasm/v1/contract/{address}/raw/{query_data}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SmartContractState',
    full_name='cosmwasm.wasm.v1.Query.SmartContractState',
    index=5,
    containing_service=None,
    input_type=_QUERYSMARTCONTRACTSTATEREQUEST,
    output_type=_QUERYSMARTCONTRACTSTATERESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/cosmwasm/wasm/v1/contract/{address}/smart/{query_data}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Code',
    full_name='cosmwasm.wasm.v1.Query.Code',
    index=6,
    containing_service=None,
    input_type=_QUERYCODEREQUEST,
    output_type=_QUERYCODERESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /cosmwasm/wasm/v1/code/{code_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Codes',
    full_name='cosmwasm.wasm.v1.Query.Codes',
    index=7,
    containing_service=None,
    input_type=_QUERYCODESREQUEST,
    output_type=_QUERYCODESRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/cosmwasm/wasm/v1/code',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PinnedCodes',
    full_name='cosmwasm.wasm.v1.Query.PinnedCodes',
    index=8,
    containing_service=None,
    input_type=_QUERYPINNEDCODESREQUEST,
    output_type=_QUERYPINNEDCODESRESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/cosmwasm/wasm/v1/codes/pinned',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/types/events.proto',
  package='tendermint.types',
  syntax='proto3',
  serialized_options=b'Z7github.com/tendermint/tendermint/proto/tendermint/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dtendermint/types/events.proto\x12\x10tendermint.types\"B\n\x13\x45ventDataRoundState\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12\r\n\x05round\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\tB9Z7github.com/tendermint/tendermint/proto/tendermint/typesb\x06proto3'
)




_EVENTDATAROUNDSTATE = _descriptor.Descriptor(
  name='EventDataRoundState',
  full_name='tendermint.types.EventDataRoundState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='tendermint.types.EventDataRoundState.height', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='tendermint.types.EventDataRoundState.round', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='step', full_name='tendermint.types.EventDataRoundState.step', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=117,
)

DESCRIPTOR.message_types_by_name['EventDataRoundState'] = _EVENTDATAROUNDSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EventDataRoundState = _reflection.GeneratedProtocolMessageType('EventDataRoundState', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDATAROUNDSTATE,
  '__module__' : 'tendermint.types.events_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.types.EventDataRoundState)
  })
_sym_db.RegisterMessage(EventDataRoundState)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from injective.auction.v1beta1 import genesis_pb2 as injective_dot_auction_dot_v1beta1_dot_genesis__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/auction/v1beta1/query.proto',
  package='injective.auction.v1beta1',
  syntax='proto3',
  serialized_options=b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/auction/v1beta1/query.proto\x12\x19injective.auction.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\'injective/auction/v1beta1/auction.proto\x1a\'injective/auction/v1beta1/genesis.proto\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x1b\n\x19QueryAuctionParamsRequest\"U\n\x1aQueryAuctionParamsResponse\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"\"\n QueryCurrentAuctionBasketRequest\"\x93\x02\n!QueryCurrentAuctionBasketResponse\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xc8\xde\x1f\x00\x12\x14\n\x0c\x61uctionRound\x18\x02 \x01(\x04\x12\x1a\n\x12\x61uctionClosingTime\x18\x03 \x01(\x03\x12\x15\n\rhighestBidder\x18\x04 \x01(\t\x12H\n\x10highestBidAmount\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\"\x19\n\x17QueryModuleStateRequest\"R\n\x18QueryModuleStateResponse\x12\x36\n\x05state\x18\x01 \x01(\x0b\x32\'.injective.auction.v1beta1.GenesisState2\xa1\x04\n\x05Query\x12\xa7\x01\n\rAuctionParams\x12\x34.injective.auction.v1beta1.QueryAuctionParamsRequest\x1a\x35.injective.auction.v1beta1.QueryAuctionParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/params\x12\xbc\x01\n\x14\x43urrentAuctionBasket\x12;.injective.auction.v1beta1.QueryCurrentAuctionBasketRequest\x1a<.injective.auction.v1beta1.QueryCurrentAuctionBasketResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/auction/v1beta1/basket\x12\xae\x01\n\x12\x41uctionModuleState\x12\x32.injective.auction.v1beta1.QueryModuleStateRequest\x1a\x33.injective.auction.v1beta1.QueryModuleStateResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/injective/auction/v1beta1/module_stateBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_auction_dot_v1beta1_dot_auction__pb2.DESCRIPTOR,injective_dot_auction_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_QUERYAUCTIONPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryAuctionParamsRequest',
  full_name='injective.auction.v1beta1.QueryAuctionParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=261,
)


_QUERYAUCTIONPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryAuctionParamsResponse',
  full_name='injective.auction.v1beta1.QueryAuctionParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.auction.v1beta1.QueryAuctionParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=348,
)


_QUERYCURRENTAUCTIONBASKETREQUEST = _descriptor.Descriptor(
  name='QueryCurrentAuctionBasketRequest',
  full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=384,
)


_QUERYCURRENTAUCTIONBASKETRESPONSE = _descriptor.Descriptor(
  name='QueryCurrentAuctionBasketResponse',
  full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse.amount', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auctionRound', full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse.auctionRound', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auctionClosingTime', full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse.auctionClosingTime', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highestBidder', full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse.highestBidder', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highestBidAmount', full_name='injective.auction.v1beta1.QueryCurrentAuctionBasketResponse.highestBidAmount', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=662,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.auction.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=689,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.auction.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.auction.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=773,
)

_QUERYAUCTIONPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_auction_dot_v1beta1_dot_auction__pb2._PARAMS
_QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_auction_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryAuctionParamsRequest'] = _QUERYAUCTIONPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryAuctionParamsResponse'] = _QUERYAUCTIONPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryCurrentAuctionBasketRequest'] = _QUERYCURRENTAUCTIONBASKETREQUEST
DESCRIPTOR.message_types_by_name['QueryCurrentAuctionBasketResponse'] = _QUERYCURRENTAUCTIONBASKETRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryAuctionParamsRequest = _reflection.GeneratedProtocolMessageType('QueryAuctionParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAUCTIONPARAMSREQUEST,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryAuctionParamsRequest)
  })
_sym_db.RegisterMessage(QueryAuctionParamsRequest)

QueryAuctionParamsResponse = _reflection.GeneratedProtocolMessageType('QueryAuctionParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAUCTIONPARAMSRESPONSE,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryAuctionParamsResponse)
  })
_sym_db.RegisterMessage(QueryAuctionParamsResponse)

QueryCurrentAuctionBasketRequest = _reflection.GeneratedProtocolMessageType('QueryCurrentAuctionBasketRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTAUCTIONBASKETREQUEST,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryCurrentAuctionBasketRequest)
  })
_sym_db.RegisterMessage(QueryCurrentAuctionBasketRequest)

QueryCurrentAuctionBasketResponse = _reflection.GeneratedProtocolMessageType('QueryCurrentAuctionBasketResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTAUCTIONBASKETRESPONSE,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryCurrentAuctionBasketResponse)
  })
_sym_db.RegisterMessage(QueryCurrentAuctionBasketResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.auction.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYAUCTIONPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['amount']._options = None
_QUERYCURRENTAUCTIONBASKETRESPONSE.fields_by_name['highestBidAmount']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.auction.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=776,
  serialized_end=1321,
  methods=[
  _descriptor.MethodDescriptor(
    name='AuctionParams',
    full_name='injective.auction.v1beta1.Query.AuctionParams',
    index=0,
    containing_service=None,
    input_type=_QUERYAUCTIONPARAMSREQUEST,
    output_type=_QUERYAUCTIONPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/injective/auction/v1beta1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CurrentAuctionBasket',
    full_name='injective.auction.v1beta1.Query.CurrentAuctionBasket',
    index=1,
    containing_service=None,
    input_type=_QUERYCURRENTAUCTIONBASKETREQUEST,
    output_type=_QUERYCURRENTAUCTIONBASKETRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/injective/auction/v1beta1/basket',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AuctionModuleState',
    full_name='injective.auction.v1beta1.Query.AuctionModuleState',
    index=2,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002)\022\'/injective/auction/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/types/v1beta1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.auth.v1beta1 import auth_pb2 as cosmos_dot_auth_dot_v1beta1_dot_auth__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/types/v1beta1/account.proto',
  package='injective.types.v1beta1',
  syntax='proto3',
  serialized_options=b'Z=github.com/InjectiveLabs/injective-core/injective-chain/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%injective/types/v1beta1/account.proto\x12\x17injective.types.v1beta1\x1a\x1e\x63osmos/auth/v1beta1/auth.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xce\x01\n\nEthAccount\x12S\n\x0c\x62\x61se_account\x18\x01 \x01(\x0b\x32 .cosmos.auth.v1beta1.BaseAccountB\x1b\xd0\xde\x1f\x01\xf2\xde\x1f\x13yaml:\"base_account\"\x12\'\n\tcode_hash\x18\x02 \x01(\x0c\x42\x14\xf2\xde\x1f\x10yaml:\"code_hash\":B\x88\xa0\x1f\x00\x98\xa0\x1f\x00\xe8\xa0\x1f\x00\xd2\xb4-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountIB?Z=github.com/InjectiveLabs/injective-core/injective-chain/typesb\x06proto3'
  ,
  dependencies=[cosmos_dot_auth_dot_v1beta1_dot_auth__pb2.DESCRIPTOR,cosmos__proto_dot_cosmos__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_ETHACCOUNT = _descriptor.Descriptor(
  name='EthAccount',
  full_name='injective.types.v1beta1.EthAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_account', full_name='injective.types.v1beta1.EthAccount.base_account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\320\336\037\001\362\336\037\023yaml:\"base_account\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code_hash', full_name='injective.types.v1beta1.EthAccount.code_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\020yaml:\"code_hash\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\210\240\037\000\230\240\037\000\350\240\037\000\322\264-2github.com/cosmos/cosmos-sdk/x/auth/types.AccountI',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=148,
  serialized_end=354,
)

_ETHACCOUNT.fields_by_name['base_account'].message_type = cosmos_dot_auth_dot_v1beta1_dot_auth__pb2._BASEACCOUNT
DESCRIPTOR.message_types_by_name['EthAccount'] = _ETHACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EthAccount = _reflection.GeneratedProtocolMessageType('EthAccount', (_message.Message,), {
  'DESCRIPTOR' : _ETHACCOUNT,
  '__module__' : 'injective.types.v1beta1.account_pb2'
  # @@protoc_insertion_point(class_scope:injective.types.v1beta1.EthAccount)
  })
_sym_db.RegisterMessage(EthAccount)


DESCRIPTOR._options = None
_ETHACCOUNT.fields_by_name['base_account']._options = None
_ETHACCOUNT.fields_by_name['code_hash']._options = None
_ETHACCOUNT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/kv/v1beta1/kv.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/kv/v1beta1/kv.proto',
  package='cosmos.base.kv.v1beta1',
  syntax='proto3',
  serialized_options=b'Z%github.com/cosmos/cosmos-sdk/types/kv',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x63osmos/base/kv/v1beta1/kv.proto\x12\x16\x63osmos.base.kv.v1beta1\x1a\x14gogoproto/gogo.proto\":\n\x05Pairs\x12\x31\n\x05pairs\x18\x01 \x03(\x0b\x32\x1c.cosmos.base.kv.v1beta1.PairB\x04\xc8\xde\x1f\x00\"\"\n\x04Pair\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\r\n\x05value\x18\x02 \x01(\x0c\x42\'Z%github.com/cosmos/cosmos-sdk/types/kvb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PAIRS = _descriptor.Descriptor(
  name='Pairs',
  full_name='cosmos.base.kv.v1beta1.Pairs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pairs', full_name='cosmos.base.kv.v1beta1.Pairs.pairs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=139,
)


_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='cosmos.base.kv.v1beta1.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.base.kv.v1beta1.Pair.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='cosmos.base.kv.v1beta1.Pair.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=141,
  serialized_end=175,
)

_PAIRS.fields_by_name['pairs'].message_type = _PAIR
DESCRIPTOR.message_types_by_name['Pairs'] = _PAIRS
DESCRIPTOR.message_types_by_name['Pair'] = _PAIR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Pairs = _reflection.GeneratedProtocolMessageType('Pairs', (_message.Message,), {
  'DESCRIPTOR' : _PAIRS,
  '__module__' : 'cosmos.base.kv.v1beta1.kv_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.kv.v1beta1.Pairs)
  })
_sym_db.RegisterMessage(Pairs)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
  'DESCRIPTOR' : _PAIR,
  '__module__' : 'cosmos.base.kv.v1beta1.kv_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.kv.v1beta1.Pair)
  })
_sym_db.RegisterMessage(Pair)


DESCRIPTOR._options = None
_PAIRS.fields_by_name['pairs']._options = None
# @@protoc_insertion_point(module_scope)
